@@ -7,9 +7,10 @@ from .itertoolz import (groupby, countby, frequencies, reduceby,
                         sliding_window, count, cons, take_nth)
 
 from .functoolz import (memoize, curry, compose, thread_first,
-                        thread_last, identity, pipe, complement)
+                        thread_last, identity, pipe, complement, juxt, do)
 
-from .dicttoolz import merge, merge_with, keymap, valmap, assoc, update_in
+from .dicttoolz import (merge, merge_with, keymap, valmap, assoc, update_in,
+                        get_in, keyfilter, valfilter)
 
 from .compatibility import map, filter
 
@@ -22,4 +23,4 @@ sorted = sorted
 # Aliases
 comp = compose
 
-__version__ = '0.5.2'
+__version__ = '0.5.3'
