@@ -38,7 +38,7 @@ def nargs(f):
 
 
 def should_curry(f):
-    do_curry = set((toolz.map, toolz.filter, toolz.sorted))
+    do_curry = set((toolz.map, toolz.filter, toolz.sorted, toolz.reduce))
     return (callable(f) and nargs(f) and nargs(f) > 1
             or f in do_curry)
 
