@@ -1,2 +1,2 @@
 from .core import (memoize, curry, thread_first, thread_last, compose,
-                   identity, pipe, complement)
+                   identity, pipe, complement, juxt, do)
