@@ -220,12 +220,12 @@ class curry(object):
 
         try:
             return self.func(*args, **kwargs)
-        except TypeError as e:
+        except TypeError:
             required_args = _num_required_args(self.func)
 
             # If there was a genuine TypeError
             if required_args is not None and len(args) >= required_args:
-                raise e
+                raise
 
             # If we only need one more argument
             if (required_args is not None and required_args - len(args) == 1):
@@ -325,3 +325,55 @@ def complement(func):
     False
     """
     return compose(operator.not_, func)
+
+
+def juxt(*funcs):
+    """
+    Creates a function that calls several functions with the same arguments.
+
+    Takes several functions and returns a function that applies its arguments
+    to each of those functions then returns a sequence of the results.
+
+    Name comes from juxtaposition: the fact of two things being seen or placed
+    close together with contrasting effect.
+
+    >>> inc = lambda x: x + 1
+    >>> double = lambda x: x * 2
+    >>> list(juxt(inc, double)(10))
+    [11, 20]
+    >>> list(juxt([inc, double])(10))
+    [11, 20]
+    """
+    if len(funcs) == 1 and not callable(funcs[0]):
+        funcs = funcs[0]
+
+    def juxt_inner(*args, **kwargs):
+        return (func(*args, **kwargs) for func in funcs)
+    return juxt_inner
+
+
+def do(func, x):
+    """ Runs ``func`` on ``x``, returns ``x``
+
+    Because the results of ``func`` are not returned, only the side
+    effects of ``func`` are relevant.
+
+    Logging functions can be made by composing ``do`` with a storage function
+    like ``list.append`` or ``file.write``
+
+    >>> from toolz import compose
+    >>> from toolz.curried import do
+
+    >>> log = []
+    >>> inc = lambda x: x + 1
+    >>> inc = compose(inc, do(log.append))
+    >>> inc(1)
+    2
+    >>> inc(11)
+    12
+    >>> log
+    [1, 11]
+
+    """
+    func(x)
+    return x
